xargs

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Xargs

type Xargs struct {
	// contains filtered or unexported fields
}

func New

func New(getter lookupGetterFunc) Xargs

New returns a new instance of xargs - it gets the filter lookup from a context which is supposed to be passed from an external environment.

func (Xargs) FromArgs

func (x Xargs) FromArgs(command string, args []string, opts ...unix.ShellContextOption) (unix.Filter, error)

func (Xargs) Run

func (x Xargs) Run(ctx context.Context, stdio unix.StandardIO) error

Jump to